﻿using AutoMapper;
using BizService;
using Model.Dto;
using Model.Entities;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.BasicConfigViewModel
{
    public class AddOrEditProjectViewModel : BindableBase, IDialogAware
    {
        private readonly IEventAggregator _aggregator;
        private readonly IBasicProjectService _iBasicProjectService;

        private readonly IMapper _mapper;
        private List<BasPlcItemConfigDto> plcConfigs = new List<BasPlcItemConfigDto>();
        private long id = 0;
        public AddOrEditProjectViewModel(IEventAggregator aggregator, IBasicProjectService iBasicProjectService, IMapper mapper)
        {
            _aggregator = aggregator;
            _iBasicProjectService = iBasicProjectService;
            _mapper = mapper;
            CloseCommand = new DelegateCommand(Close);
            SureCommand = new DelegateCommand<string>(Sure);
            CancelCommand = new DelegateCommand(Close);

        }






        #region idialog接口实现
        public string Title { set; get; } = "新增项目";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {

        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            var getMsg = parameters.GetValues<BasProjectDto>("Key");
            ///值不为空，表示修改
            if (getMsg != null)
            {
                foreach (var item in getMsg)
                {
                    if (item != null)
                    {
                        Title = "修改项目";

                        ProjectName = item.ProjectName;
                        ProjectNo = item.ProjectNo;
                        ProjectLeader = item.ProjectLeader;
                        Remark = item.Remark;

                    }

                }

            }
        }

        #endregion
        #region 私有方法


        private void Close()
        {
            RequestClose?.Invoke(new DialogResult(ButtonResult.Cancel));
        }
        /// <summary>
        /// 确认
        /// </summary>
        /// <param name="obj"></param>
        private void Sure(string obj)
        {
            if (string.IsNullOrEmpty(ProjectName))
            {
                MessageBox.Show("请填写项目名称！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (string.IsNullOrEmpty(ProjectNo))
            {
                MessageBox.Show("请填写项目编号！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (string.IsNullOrEmpty(ProjectLeader))
            {
                MessageBox.Show("请选择项目负责人！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }

            BasProjectDto basProject = new BasProjectDto();
            basProject.ProjectName = ProjectName;
            basProject.ProjectNo = ProjectNo;
            basProject.ProjectLeader = ProjectLeader;
            basProject.Remark = Remark;

            DialogParameters parm = new DialogParameters();
            parm.Add("ReturnValue", basProject);
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK, parm));
        }
        /// <summary>
        /// 重置
        /// </summary>
        /// <param name="obj"></param>
        private void ResetMethod(string obj)
        {

        }
      
        #endregion



        #region 命令绑定
        public DelegateCommand CloseCommand { set; get; }
        public DelegateCommand<string> SureCommand { set; get; }
        public DelegateCommand CancelCommand { set; get; }
        public DelegateCommand TxtLostFocusCommand { set; get; }
        public DelegateCommand TxtPLCValueLostFocusCommand { set; get; }


        #endregion
        #region 变量绑定
        private string projectName;
        public string ProjectName
        {
            get { return projectName; }
            set { projectName = value; RaisePropertyChanged(); }
        }

        private string projectNo;
        public string ProjectNo
        {
            get { return projectNo; }
            set { projectNo = value; RaisePropertyChanged(); }
        }
        private string projectLeader;
        public string ProjectLeader
        {
            get { return projectLeader; }
            set { projectLeader = value; RaisePropertyChanged(); }
        }

        private string remark;
        public string Remark
        {
            get { return remark; }
            set { remark = value; RaisePropertyChanged(); }
        }

        #endregion
    }
}