﻿using AutoMapper;
using BizService;
using BlankApp1.Events;
using Microsoft.Extensions.Logging;
using MiniExcelLibs;
using Model;
using Model.Dto;
using Model.Entities;
using PLCTool.Events;
using PLCTool.Models;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Regions;
using Prism.Services.Dialogs;

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;


namespace PLCTool.ViewModels.BasicConfigViewModel
{
    public class BaseConfigViewModel : BindableBase
    {
        private readonly IDialogService _dialog;
        private readonly IEventAggregator _aggregator;
        private readonly IRegionManager _regionManager;
        private readonly IOptionConfigService _optionConfigService;
        private readonly IBasicPlcTestSchemeService _basicPlcTestSchemeService;
        private readonly IBasicPlcTestSchemeDtlService _basicPlcTestSchemeDtlService;
        private readonly IBasicDeviceKindService _iBasicDeviceKindService;
        private readonly ILogger _logger;
        private readonly IMapper _mapper;
        private readonly IMenuService _menuService;

        private List<BasicPlcTestSchemeDto> allConfigList = new List<BasicPlcTestSchemeDto>();//所有方案
        private List<BasicPlcTestSchemeDto> conditionConfig = new List<BasicPlcTestSchemeDto>();//符合条件的方案

        private const int PageCount = 1; //每一页显示个数
        private List<CrumbViewModel> breadCrumbs = new List<CrumbViewModel>();
        public BaseConfigViewModel(IDialogService dialog, IEventAggregator aggregator, IRegionManager regionManager, IMenuService menuService, IOptionConfigService optionConfigService, IBasicPlcTestSchemeService basicPlcTestSchemeService, IBasicPlcTestSchemeDtlService basicPlcTestSchemeDtlService , IBasicDeviceKindService iBasicDeviceKindService, IMapper mapper, ILogger logger)
        {
            _dialog = dialog;
            _aggregator = aggregator;
            _regionManager= regionManager;
            _optionConfigService = optionConfigService;
            _basicPlcTestSchemeService = basicPlcTestSchemeService;
            _basicPlcTestSchemeDtlService = basicPlcTestSchemeDtlService;
            _iBasicDeviceKindService = iBasicDeviceKindService;
            _logger = logger;
            _mapper = mapper;
            _menuService = menuService;
            QueryCommand = new DelegateCommand<object>(Query);
            ResetCommand = new DelegateCommand<object>(Reset);
            ExportCommand = new DelegateCommand<string>(Export);
            AddPlanCommand = new DelegateCommand<string>(AddPlan);
            EditCommand = new DelegateCommand<object>(Edit);
            DeleteCommand = new DelegateCommand<object>(Delete);
            CopyCommand = new DelegateCommand<object>(Copy);
            OnLoadCommand = new DelegateCommand(OnLoad);
            ReadDetailCommand = new DelegateCommand<object>(ReadDetail);
            GetConfigOption();
            GetContent();
            //添加或修改方案后重新读取
            _aggregator.GetEvent<ChangeEvent>().Subscribe((s) =>
            {
                GetContent();
            });
           
        }



        #region 私有方法


        private void OnLoad()
        {
           
            DeviceKindNameList.Clear();
            DeviceKindNameList.Add("---");
            var kinds = _iBasicDeviceKindService.FindAllDeviceKind();
            foreach (var kind in kinds)
            {
                DeviceKindNameList.Add(kind);
            }
            DeviceKindName = "---";

            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "基础设置",NavigateRegion="BaseConfigView" });
            breadCrumbs.Add(new CrumbViewModel { Name = "测试方案配置", NavigateRegion = "BaseConfigView" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);

        }

        /// <summary>
        /// 查看详情
        /// </summary>
        /// <param name="obj"></param>

        private void ReadDetail(object obj)
        {
           

            //测试方案明细主键ID
            long schid = (long)obj;
       
            DialogParameters parm = new DialogParameters();
            parm.Add("Key", schid);
            //弹出详情对话框
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(true);
            _dialog.ShowDialog("ReadSchView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    //更新表格，重新获取

                }

            });
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(false);
        }
        /// <summary>
        /// 复位
        /// </summary>
        /// <param name="obj"></param>

        private void Reset(object obj)
        {
            ScheduleName = string.Empty;
            DeviceKindName = "---";
            TestName = string.Empty;
            SelectTest = string.Empty;
            StartTime = string.Empty;
            EndTime = string.Empty;
        }
        /// <summary>
        /// 查询
        /// </summary>
        /// <param name="obj"></param>
        private void Query(object obj)
        {

            if ((!string.IsNullOrEmpty(StartTime)) && (!string.IsNullOrEmpty(EndTime)))
            {
                if (Convert.ToDateTime(StartTime) > Convert.ToDateTime(EndTime))
                {
                    MessageBox.Show("起始时间大于结束时间，请重新输入", "确认", MessageBoxButton.OK, MessageBoxImage.Warning);
                    return;
                }

            }

            try
            {
                conditionConfig = (from a in allConfigList
                                   where (EndTime == string.Empty ? true : (a.CreateTime < Convert.ToDateTime(EndTime)) && (Convert.ToDateTime(StartTime) < a.CreateTime))
                                    && (string.IsNullOrEmpty(ScheduleName) ? true : (a.SchemeName == ScheduleName))
                                      && (DeviceKindName == "---") ? true : (a.DeviceKindName == DeviceKindName)
                                   select a).ToList();
                //默认显示的第一页
                conditionConfig = conditionConfig.OrderBy(x => x.SchemeName).ThenBy(x => x.SchemeId).ToList();
                Getpage();
            }
            catch(Exception ex)
            {
                _logger.LogError(ex.ToString());
            }

            //BaseConfigList = new ObservableCollection<BasicPlcTestSchemeDto>(conditionConfig);
        }
        /// <summary>
        /// 获取配置
        /// </summary>
        private void GetConfigOption()
        {
            var configList = _optionConfigService.QueryList();
            var _optionConfigs = _mapper.Map<List<OptionConfig>, List<OptionConfigDto>>(configList);
            var tests = _optionConfigs.FindAll(x => x.TypeID == 1);
            TestKinds = new List<string>();
            foreach (var test in tests)
            {
                TestKinds.Add(test.ContentOption);
            }
        }
        /// <summary>
        /// 编辑
        /// </summary>
        /// <param name="obj"></param>
         private void Edit(object obj)
        {
            //测试方案明细主键ID
            object[] multiObj = obj as object[];

            //测试方案名称和设备类型
            string schemeName = (string)multiObj[0];
            string deviceKindName = (string)multiObj[1];
            long schemeId = (long)multiObj[2];
            NavigationParameters parm = new NavigationParameters();
            parm.Add("Key", schemeName);
            parm.Add("Key2", deviceKindName);
            parm.Add("Key3", schemeId);
            _regionManager.Regions["ContentRegion"].RequestNavigate("EditSchView", async callback =>
            {
                if (callback.Result == true)
                {
                    //更新表格，重新获取
                    GetContent();
                }

            },parm);
            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "基础设置", NavigateRegion = "BaseConfigView" });
            breadCrumbs.Add(new CrumbViewModel { Name = "测试方案配置", NavigateRegion = "BaseConfigView" });
            breadCrumbs.Add(new CrumbViewModel { Name = "编辑测试方案" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);

        }
        /// <summary>
        /// 删除操作
        /// </summary>
        /// <param name="obj"></param>
        private void Delete(object obj)
        {
            int id = Convert.ToInt32(obj);
            MessageBoxResult boxResult = MessageBox.Show("确认删除此条数据?", "确认", MessageBoxButton.OKCancel, MessageBoxImage.Question);
            if (boxResult == MessageBoxResult.OK)
            {
                //查找测试方案名称的id
                var schDtls = _basicPlcTestSchemeDtlService.FindAllBySchId(id);
                foreach(var item in schDtls)
                {
                    _basicPlcTestSchemeDtlService.Delete((int)item.scheme_dtl_id);
                }
                //删除测试方案
                _basicPlcTestSchemeService.Delete(id);

                //更新表格，重新获取
                GetContent();
            }
        }
        /// <summary>
        /// 复制方案
        /// </summary>
        /// <param name="obj"></param>
        private void Copy(object obj)
        {
            //测试方案名称
            string  schName = obj.ToString();
            DialogParameters parm = new DialogParameters();
            parm.Add("Key", schName);
            //弹出详情对话框
            _dialog.ShowDialog("CopySchView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    //更新表格，重新获取
                    GetContent();
                }

            });
        }
        /// <summary>
        /// 新增按钮
        /// </summary>
        /// <param name="obj"></param>
        private void AddPlan(string obj)
        {
            _regionManager.Regions["ContentRegion"].RequestNavigate("AddSchView");
            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "基础设置", NavigateRegion = "BaseConfigView" });
            breadCrumbs.Add(new CrumbViewModel { Name = "测试方案配置", NavigateRegion = "BaseConfigView" });
            breadCrumbs.Add(new CrumbViewModel { Name = "新增测试方案" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
        }
        /// <summary>
        /// excel导出
        /// </summary>
        /// <param name="obj"></param>
        private void Export(object obj)
        {


            using (System.Windows.Forms.SaveFileDialog saveFileDialog = new System.Windows.Forms.SaveFileDialog()
            {
                //设置文件类型
                //书写规则例如：txt files(*.txt)|*.txt
                Filter = "Excel files(*.xlsx)|*.xlsx|All files(*.*)|*.*",
                //设置默认文件名（可以不设置）
                FileName = "配置导出" + string.Format("{0:yyyyMMddHHmm}", DateTime.Now),

                //获取或设置一个值，该值指示如果用户省略扩展名，文件对话框是否自动在文件名中添加扩展名。（可以不设置）
                AddExtension = true,

                //保存对话框是否记忆上次打开的目录
                RestoreDirectory = true
            })
            {
                // Show save file dialog box

                //点了保存按钮进入
                if (saveFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    try
                    {
                        //获得文件路径
                        string localFilePath = saveFileDialog.FileName.ToString();

                        //string filePathWithName = localFilePath + ".xlsx";

                        //获取文件内容
                        MiniExcel.SaveAs(localFilePath, BaseConfigList);
                    }
                    catch (Exception ex)
                    {
                        _logger.LogError(ex.ToString());
                    }


                }

            }
        }
        /// <summary>
        /// 获取解决方案
        /// </summary>
        private void GetContent()
        {
            int count = 0;
            //所有测试方案
            var schlist = _basicPlcTestSchemeService.QueryList();
            var configList = _mapper.Map<List<bas_plc_test_scheme>, List<BasicPlcTestSchemeDto>>(schlist);
            //清空集合
            BaseConfigList.Clear();
            allConfigList.Clear();
            conditionConfig.Clear();
            //查找测试项名称
            foreach (var sch in configList)
            {
                count++;
                sch.DisId = count;
                allConfigList.Add(sch);
                conditionConfig.Add(sch);

            }
            conditionConfig = conditionConfig.OrderBy(x => x.DisId).ThenBy(x => x.DeviceKindName).ToList();
            //默认显示的第一页
            Getpage();
        }

        /// <summary>
        /// 获取页面
        /// </summary>
        private void Getpage()
        {
            CurrentPage = 1;
            TotalCount = conditionConfig.Count;
            CurrentPageChanged();


        }
        /// <summary>
        /// 页面变化
        /// </summary>
        private void CurrentPageChanged()
        {

            BaseConfigList.Clear();

            foreach (var i in conditionConfig.Skip((CurrentPage - 1) * CountPerPage).Take(CountPerPage))
            {
                BaseConfigList.Add(i);
            }
        }
        #endregion
        #region 命令绑定

        public DelegateCommand<object> EditCommand { set; get; }
        public DelegateCommand<string> AddPlanCommand { set; get; }
        public DelegateCommand<object> QueryCommand { set; get; }
        public DelegateCommand<object> ResetCommand { set; get; }
        public DelegateCommand<object> DeleteCommand { set; get; }
        public DelegateCommand<object> CopyCommand { set; get; }
        public DelegateCommand<string> ExportCommand { set; get; }
        
        public DelegateCommand OnLoadCommand { set; get; }

        public DelegateCommand<object> ReadDetailCommand { set; get; }
        #endregion
        #region 数据绑定
        /// <summary>
        /// 测试方案编码
        /// </summary>
        private string scheduleName;
        public string ScheduleName
        {
            get { return scheduleName; }
            set { scheduleName = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 设备名称
        /// </summary>
        private string deviceKindName;
        public string DeviceKindName
        {
            get { return deviceKindName; }
            set { deviceKindName = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 设备类型
        /// </summary>
        private ObservableCollection<string> deviceKindNameList = new ObservableCollection<string>();
        public ObservableCollection<string> DeviceKindNameList
        {
            get { return deviceKindNameList; }
            set { deviceKindNameList = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 测试项名称
        /// </summary>
        private string testName;
        public string TestName
        {
            get { return testName; }
            set { testName = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 测试项类型
        /// </summary>
      
  
        private List<string> testKinds = new List<string>();
        public List<string> TestKinds
        {
            get { return testKinds; }
            set { testKinds = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 
        /// </summary>
        private string selectTest;
        public string SelectTest
        {
            get { return selectTest; }
            set { selectTest = value; RaisePropertyChanged(); }
        }

        private string startTime = DateTime.Now.AddHours(-1).ToString();
        public string StartTime
        {
            get { return startTime; }
            set { startTime = value; RaisePropertyChanged(); }
        }
        private string endTime =DateTime.Now.ToString();
        public string EndTime
        {
            get { return endTime; }
            set { endTime = value; RaisePropertyChanged(); }
        }

        /// <summary>
        /// 总条数
        /// </summary>
        private int totalCount;
        public int TotalCount
        {
            get { return totalCount; }
            set { totalCount = value; RaisePropertyChanged(); CurrentPageChanged(); }
        }
        /// <summary>
        /// 每页数量
        /// </summary>
        private int countPerPage = 15;
        public int CountPerPage
        {
            get { return countPerPage; }
            set { countPerPage = value; RaisePropertyChanged(); CurrentPageChanged(); }
        }
        /// <summary>
        /// 单前页
        /// </summary>
        private int currentPage = 1;
        public int CurrentPage
        {
            get { return currentPage; }
            set { currentPage = value; RaisePropertyChanged(); CurrentPageChanged(); }
        }

        private ObservableCollection<BasicPlcTestSchemeDto> baseConfigList = new ObservableCollection<BasicPlcTestSchemeDto>();
        public ObservableCollection<BasicPlcTestSchemeDto> BaseConfigList
        {
            get { return baseConfigList; }
            set { SetProperty(ref baseConfigList, value); }
        }

        #endregion

    }
}
