﻿using AutoMapper;
using BizService;
using ImTools;
using Microsoft.Extensions.Logging;
using Model.Dto;
using Model.Entities;
using PLCTool.Common;
using PLCTool.Models;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net.NetworkInformation;
using System.Security.Cryptography.Xml;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Automation;
using static System.Windows.Forms.VisualStyles.VisualStyleElement.ListView;

namespace PLCTool.ViewModels.BasicConfigViewModel
{
    internal class CopySchViewModel : BindableBase, IDialogAware
    {
        private readonly IMapper _mapper;
        private readonly ILogger _logger;
        private readonly IBasicPlcTestSchemeService _basicPlcTestSchemeService;
        private readonly IBasicPlcTestSchemeDtlService _basicPlcTestSchemeDtlService;
        private string tyepName = String.Empty;
 

        public CopySchViewModel(IDialogService dialog, IEventAggregator aggregator, IOptionConfigService optionConfigService, IBasicPlcTestSchemeService basicPlcTestSchemeService, IBasicPlcTestSchemeDtlService basicPlcTestSchemeDtlService, IMapper mapper, ILogger logger)
        {
            
            _basicPlcTestSchemeService = basicPlcTestSchemeService;
            _basicPlcTestSchemeDtlService = basicPlcTestSchemeDtlService;
            _mapper = mapper;
            _logger = logger;
            SureCommand = new DelegateCommand<string>(Sure);
            UpCommand = new DelegateCommand<object>(DataUp);
            DownCommand = new DelegateCommand<object>(DataDown);
            SelectAllCommand = new DelegateCommand<object>(SelectAll);
            UnSelectAllCommand = new DelegateCommand<object>(UnSelecttAll);
        }

        private void UnSelecttAll(object obj)
        {
            SchProjectList.ToList().FindAll(p => p.IsSelected = false);
        }

        private void SelectAll(object obj)
        {
            SchProjectList.ToList().FindAll(p => p.IsSelected = true);
        }

        /// <summary>
        /// 下移
        /// </summary>
        /// <param name="obj"></param>
        private void DataDown(object obj)
        {
            int id = Convert.ToInt32(obj);
            var findScheExist = SchProjectList.FirstOrDefault(x => x.SchDtlId == id);
            if (findScheExist != null)
            {

                int index = SchProjectList.IndexOf(findScheExist);
                if(index!=-1)
                {
                    if (index == SchProjectList.Count - 1)
                        return;
                    SchProjectList.RemoveAt(index);
                    index = index + 1;
                    SchProjectList.Insert(index, findScheExist);
                }
        

            }
        }
        /// <summary>
        /// 上移
        /// </summary>
        /// <param name="obj"></param>
        private void DataUp(object obj)
        {
            int id = Convert.ToInt32(obj);
            var findScheExist = SchProjectList.FirstOrDefault(x=>x.SchDtlId==id);
            if (findScheExist != null)
            {

                int index = SchProjectList.IndexOf(findScheExist);
                if(index!=-1)
                {
                    if (index == 0)
                        return;
                    SchProjectList.RemoveAt(index);
                    index = index - 1;
                    SchProjectList.Insert(index, findScheExist);
                }
               

            }

        }

  
        private void Sure(string obj)
        {
            //查找是否有这个测试方案
         
            var findSelect = SchProjectList.FirstOrDefault(x => x.IsSelected == true);
            if (findSelect == null)
            {
                MessageBoxResult boxResult = MessageBox.Show("请勾选测试项！", "提示", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }
            //查找的信息
            var finsSche = _basicPlcTestSchemeService.FindByName(ScheduleName);
            try
            {
                //没有此测试方案，就增加
                if (finsSche == null)
                {
               
                    //增加测试方案到数据库
                    bas_plc_test_scheme schDto = new bas_plc_test_scheme();
                    schDto.scheme_name = ScheduleName;
                    schDto.devicekind_name = DeviceKindName;
                    schDto.create_by = Appsession.UserName;
                    schDto.create_time = DateTime.Now;
                    schDto.update_time = DateTime.Now;
                    schDto.update_by = Appsession.UserName;
                    _basicPlcTestSchemeService.Add(schDto);
 
                }
           
                //查找此方案下id
                long? schINewID = _basicPlcTestSchemeService.FindByName(ScheduleName)?.scheme_id;
                //这里要注意顺序，所以用了SchProjectList循环
                //增加测试方案明细
                foreach (var sch in SchProjectList)
                {
                    if (sch.IsSelected)
                    {
                        int dtlId = Convert.ToInt32(sch.SchDtlId);
                        var unit = _basicPlcTestSchemeDtlService.Find(dtlId);
                        if (unit != null)
                        {
                            bas_plc_test_scheme_dtl schDtlDto = new bas_plc_test_scheme_dtl();
                            schDtlDto.scheme_id = schINewID;
                            schDtlDto.item_name = unit.item_name;

                            schDtlDto.item_type = unit.item_type;
                            schDtlDto.precondition = unit.precondition;
                            schDtlDto.precondition_describe = unit.precondition_describe;
                            schDtlDto.action = unit.action;
                            schDtlDto.action_describe = unit.action_describe;
                            schDtlDto.judgement_result = unit.judgement_result;
                            schDtlDto.judgement_result_describe = unit.judgement_result_describe;
                            schDtlDto.create_by = Appsession.UserName;
                            schDtlDto.create_time = DateTime.Now;
                            schDtlDto.update_time = DateTime.Now;
                            schDtlDto.update_by = Appsession.UserName;
                            //先把方案明细添加到数据库中
                            bool isAddSucc = _basicPlcTestSchemeDtlService.Add(schDtlDto);

                        }
                    }


                }

            }
            catch (Exception ex)
            {
                _logger.LogError(ex.ToString());
            }
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
        }

        public string Title { set; get; } ="选择测试项";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {
            
        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            ObservableCollection<SelectItemModel> existItems = new ObservableCollection<SelectItemModel>();

           ///获取已有的测试项
           var getMsg3 = parameters.GetValues<ObservableCollection<SelectItemModel>>("Key3");

            if (getMsg3 != null)
            {
                foreach (var item in getMsg3)
                {
                    existItems = item;
                }
            }

            //设备类型
            var getMsg = parameters.GetValues<string>("Key");
            
            if (getMsg != null)
            {
                try
                {
                    foreach (var item in getMsg)
                    {
                        tyepName = item.ToString();
                        DeviceKindName = tyepName;
                        var findSchs = _basicPlcTestSchemeService.FindAllByKind(tyepName);
                        foreach(var findSche in findSchs)
                        {
                            //显示方案id
                    
                            long schID = findSche.scheme_id;
                            //查找此方案下的所有的测试项,并增加到表格
                            var schDtls = _basicPlcTestSchemeDtlService.QueryList()?.FindAll(x => x.scheme_id == schID);
                            foreach (var unit in schDtls)
                            {
                                string itemType = string.Empty;
                                switch (unit.item_type)
                                {
                                    case 0:
                                        itemType = "前置项";
                                        break;
                                    case 1:
                                        itemType = "PLC点位测试项";
                                        break;
                                    case 2:
                                        itemType = "Robot动作测试";
                                        break;
                                }
                                //添加列举此测试方案下没有的测试项
                                var resu = existItems.FirstOrDefault(x => x.ItemName == unit.item_name);
                                if(resu==null)
                                {
                                    SchProjectList.Add(new SelectItemModel
                                    {
                                        SchDtlId = unit.scheme_dtl_id,
                                        ItemName = unit.item_name,
                                        ItemType = itemType,
                                    });
                                }
                           

                            }
                        }
                    }
                }
                catch(Exception ex)
                {
                    _logger.LogError(ex.ToString());
                }
                
            }
            //获取测试方案名称
            var getMsg2 = parameters.GetValues<string>("Key2");
            if(getMsg2 != null) 
            {
                foreach (var item in getMsg2)
                {
                    ScheduleName = item;
                }
            }

        }
        #region 命令绑定
        public DelegateCommand<string> SureCommand { set; get; }
        
               
        public DelegateCommand<object> DownCommand { set; get; }
        public DelegateCommand<object> UpCommand { set; get; }
        public DelegateCommand<object> SelectAllCommand { set; get; }
        public DelegateCommand<object> UnSelectAllCommand { set; get; }

        #endregion
        #region 数据绑定
        /// <summary>
        /// 测试方案编码
        /// </summary>
        private string scheduleName;
        public string ScheduleName
        {
            get { return scheduleName; }
            set { scheduleName = value; RaisePropertyChanged(); }
        }
        /// <summary>
        /// 设备名称
        /// </summary>
        private string deviceKindName;
        public string DeviceKindName
        {
            get { return deviceKindName; }
            set { deviceKindName = value; RaisePropertyChanged(); }
        }


        private ObservableCollection<SelectItemModel> schProjectList = new ObservableCollection<SelectItemModel>();
        public ObservableCollection<SelectItemModel> SchProjectList
        {
            get { return schProjectList; }
            set { SetProperty(ref schProjectList, value); }
        }

    
        #endregion

    }
}
