﻿using AutoMapper;
using BizService;
using Microsoft.Extensions.Logging;
using Model;
using Model.Dto;
using Model.Entities;
using PLCTool.Common;
using PLCTool.Events;
using PLCTool.Models;
using PLCTool.Views.BusinessManageView;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WPFDevelopers.Helpers;
using static System.Net.Mime.MediaTypeNames;

namespace PLCTool.ViewModels.BusinessManageViewModel
{
    public  class ProjectTestViewModel:BindableBase
    {
        

        private readonly IBasicDeviceService _iBasicDeviceService;
        private readonly IBasicDeviceKindService _iBasicDeviceKindService;
        private readonly IBasicProjectService _iBasicProjectService;
        private readonly IBizTestRecordService _iBizTestRecordService;
        private readonly IRoleProjectService _iRoleProjectService;
        private readonly IMapper _mapper;
        private readonly IDialogService _dialog;
        private readonly ILogger _logger;
        private readonly IEventAggregator _aggregator;
        private ObservableCollection<DeviceTestCardView> allProjectePicList = new ObservableCollection<DeviceTestCardView>();
        private int eachColumNum = 4; //每行展示卡片个数
        private List<CrumbViewModel> breadCrumbs = new List<CrumbViewModel>();
        public ProjectTestViewModel(IBasicDeviceService iBasicDeviceService, IBasicDeviceKindService iBasicDeviceKindService, IBasicProjectService iBasicProjectService, IBizTestRecordService iBizTestRecordService, IRoleProjectService iRoleProjectService,IMapper mapper, IDialogService dialog, ILogger logger, IEventAggregator aggregator)
        {
            _iBasicDeviceService = iBasicDeviceService;
            _iBasicDeviceKindService = iBasicDeviceKindService;
            _iBasicProjectService = iBasicProjectService;
            _iBizTestRecordService = iBizTestRecordService;
            _iRoleProjectService= iRoleProjectService;
            _mapper = mapper;
            _dialog = dialog;
            _logger = logger;
            _aggregator=aggregator;
            OnLoadCommand = new DelegateCommand(OnLoad);
            QueryCommand = new DelegateCommand<object>(Query);
            ResetCommand = new DelegateCommand<object>(Reset);
        }
        #region 私有方法
        private void Reset(object obj)
        {
            ProjectNo = string.Empty;
            ProjectLeader = string.Empty;
            ProjectName = string.Empty;
            StartTime = string.Empty;
            EndTime = string.Empty;
        }

        private void Query(object obj)
        {
            try
            {
                var conditions = (from a in allProjectePicList
                                  where (string.IsNullOrEmpty(ProjectNo) ? true : (a.txtProjectNo.Text == ProjectNo))
                                  && (string.IsNullOrEmpty(ProjectName) ? true : (a.txtName.Text == ProjectName))
                                    && (string.IsNullOrEmpty(ProjectLeader) ? true : (a.txtPProjectLeader.Text == ProjectLeader))
                                    && (EndTime == string.Empty ? true : (Convert.ToDateTime(a.txtCreateTime.Text) < Convert.ToDateTime(EndTime)) && (Convert.ToDateTime(StartTime) < Convert.ToDateTime(a.txtCreateTime.Text)))
                                  select a).ToList();
                ProjectePicList = new ObservableCollection<DeviceTestCardView>(conditions);
            }
            catch (Exception ex)
            {
                _logger.LogError(ex.ToString());
            }
           
        }

        private void OnLoad()
        {
            GetProjectConfig();
            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "业务管理" });
            breadCrumbs.Add(new CrumbViewModel { Name = "测试操作", NavigateRegion = "ProjectTestView" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
        }

        /// <summary>
        /// 获取所有项目
        /// </summary>
        private void GetProjectConfig()
        {
          
            ProjectePicList.Clear();
            allProjectePicList.Clear();
            List<BasDeviceWithSchModel> allDeviceList = new List<BasDeviceWithSchModel>();//所有方案
            var devicelist = _iBasicDeviceService.QueryList();
            var allDeviceKinds = _mapper.Map<List<bas_device>, List<BasDeviceDto>>(devicelist);
            try
            {
                //遍历设备类型
                foreach (var item in allDeviceKinds)
                {
                    string deviceKind = _iBasicDeviceKindService.Find((int)item.DeviceKindId)?.devicekind_name;
                    allDeviceList.Add(new BasDeviceWithSchModel()
                    {
                        ProjectId = item.ProjectId,
                        DeviceId = item.DeviceId,
                        DeviceNo = item.DeviceNo,
                        DeviceName = item.DeviceName,
                        DeviceKindName = _iBasicDeviceKindService.Find((int)item.DeviceKindId)?.devicekind_name,
                        ProjectName = _iBasicProjectService.Find((int)item.ProjectId)?.project_name,

                    });


                }
                //所有的项目
                List<string> projectNames = new List<string>();
                //根据角色显示所拥有的项目
                var roleProjectIds=_iRoleProjectService.FindAllByRoleId(Appsession.RoleId);
                foreach(var item in roleProjectIds)
                {
                    var finPro= _iBasicProjectService.Find((int)item.ProjectId);
                    if(finPro!=null)
                    {
                        projectNames.Add(finPro.project_name);
                    }
                }
                //遍历项目
                foreach (var project in projectNames)
                {
                    int noTestCount = 0;

                    var devices = allDeviceList?.FindAll(x => x.ProjectName == project)?.Select(x => x.DeviceId)?.Distinct();
                    //计算未测试的数量
                    foreach (var deviceid in devices)
                    {
                        var findResult = _iBizTestRecordService.FindRecordByDeviceId(deviceid);
                        if (findResult.Count == 0)
                        {
                            noTestCount++;
                        }
                    }
                    int deviceCount = devices.Count();
                    //添加卡片
                    DeviceTestCardView deviceCard = new DeviceTestCardView();
                    //创建时间
                    deviceCard.txtCreateTime.Text = _iBasicProjectService.FindByProjectName(project)?.create_time.ToString();
                    deviceCard.txtName.Text = project;
                    deviceCard.txtProjectNo.Text = _iBasicProjectService.FindByProjectName(project)?.project_no;
                    deviceCard.txtPProjectLeader.Text = _iBasicProjectService.FindByProjectName(project)?.project_leader;
                    deviceCard.txtDeviceCount.Text = deviceCount.ToString() + " 台"; ;
                    deviceCard.txtNoTestCount.Text = noTestCount.ToString() + " 台";
                    //赋值
                    allProjectePicList.Add(deviceCard);
                }

                foreach (var item in allProjectePicList)
                {

                    ProjectePicList.Add(item);

                }

                //计算行数
                if (ProjectePicList.Count % eachColumNum == 0)
                {
                    RowsCount = ProjectePicList.Count / eachColumNum;
                }
                else
                {
                    RowsCount = ProjectePicList.Count / eachColumNum + 1;
                }
                if (RowsCount < 2)
                {
                    RowsCount = 2;
                }

            }
            catch (Exception ex)
            {
                _logger.LogError(ex.ToString());
            }
        

        }
        #endregion

        #region 命令绑定
        public DelegateCommand OnLoadCommand { set; get; }
        public DelegateCommand<object> QueryCommand { set; get; }




        public DelegateCommand<object> ResetCommand { set; get; }
       
        #endregion

        #region 数据绑定
        /// <summary>
        /// 设备卡片
        /// </summary>

        private ObservableCollection<DeviceTestCardView> projectPicList=new ObservableCollection<DeviceTestCardView>();
        public ObservableCollection<DeviceTestCardView> ProjectePicList
        {
            get { return projectPicList; }
            set { projectPicList = value; RaisePropertyChanged(); }
        }

        private int rowsCount =2;
        public int RowsCount
        {
            get { return rowsCount; }
            set { rowsCount = value; RaisePropertyChanged(); }
        }

        private string projectNo;
        public string ProjectNo
        {
            get { return projectNo; }
            set { projectNo = value; RaisePropertyChanged(); }
        }

        private string projectName;
        public string ProjectName
        {
            get { return projectName; }
            set { projectName = value; RaisePropertyChanged(); }
        }
        private string projectLeader;
        public string ProjectLeader
        {
            get { return projectLeader; }
            set { projectLeader = value; RaisePropertyChanged(); }
        }

        /// <summary>
        /// 开始时间
        /// </summary>
        private string startTime = DateTime.Now.AddDays(-1).ToString();
        public string StartTime
        {
            get { return startTime; }
            set { startTime = value; RaisePropertyChanged(); }
        }
        private string endTime = DateTime.Now.ToString();
        public string EndTime
        {
            get { return endTime; }
            set { endTime = value; RaisePropertyChanged(); }
        }

        #endregion
    }
}
