﻿using NLog;
using PLCTool.Events;
using PLCTool.Models;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.MonitorManageViewModel
{
    public  class LogViewModel:BindableBase
    {
        private readonly IEventAggregator _aggregator;
        private List<CrumbViewModel> breadCrumbs = new List<CrumbViewModel>();
        public LogViewModel(IEventAggregator aggregator) 
        { 
            _aggregator = aggregator;
            OnLoadCommand = new DelegateCommand(OnLoad);
            StartCommand = new DelegateCommand(Start);
            StopCommand = new DelegateCommand(Stop);
            CleanCommand = new DelegateCommand(Clean);
        }

        private void Clean()
        {
            Application.Current.Dispatcher.Invoke(() =>
            {
                LogMessages.Clear();
            });
        }

        private void Stop()
        {
            _aggregator.GetEvent<LogEvent>().Unsubscribe(OnLogEvent);
        }

        private void Start()
        {
            _aggregator.GetEvent<LogEvent>().Subscribe(OnLogEvent);
        }

        private void OnLoad()
        {
            
            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "监控管理" });
            breadCrumbs.Add(new CrumbViewModel { Name = "系统实时Log" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
           
        }

        private void OnLogEvent(LogMessage logMessage)
        {
            Application.Current.Dispatcher.Invoke(() =>
            {
                LogMessages.Add($"{logMessage.LogTime}:  {logMessage.LogMsg}");
            });
        }
        public DelegateCommand OnLoadCommand { set; get; }
        public DelegateCommand StartCommand { set; get; }
        public DelegateCommand StopCommand { set; get; }
        public DelegateCommand CleanCommand { set; get; }
        private ObservableCollection<string> logMessages=new ObservableCollection<string>();

        public ObservableCollection<string> LogMessages
        {
            get { return logMessages; }
            set { SetProperty(ref logMessages, value); }
        }

    }
}
