﻿using BlankApp1.Common;
using PLCTool.Events;
using PLCTool.Models;
using PLCTool.Views.MonitorManageView;
using Prism.Commands;
using Prism.Events;
using Prism.Regions;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace PLCTool.ViewModels.MonitorManageViewModel
{
    public  class PLCPointViewModel
    {
        private readonly IEventAggregator _aggregator;
        private readonly IRegionManager _regionManager;
        private List<CrumbViewModel> breadCrumbs = new List<CrumbViewModel>();
        public PLCPointViewModel(IEventAggregator aggregator,IRegionManager regionManager)
        {
            _aggregator = aggregator;
            _regionManager = regionManager; 
            ButtonNavigateCommand = new DelegateCommand<string>(NavigateMethod);
            OnLoadCommand = new DelegateCommand(OnLoad);
        }

        private void OnLoad()
        {
            _regionManager.Regions["PLCRegion"].RequestNavigate("PLCReadView");
            //发布面包靴
            breadCrumbs.Clear();
            breadCrumbs.Add(new CrumbViewModel { Name = "监控管理" });
            breadCrumbs.Add(new CrumbViewModel { Name = "PLC点位监控" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);

        }

        private void NavigateMethod(string strPar)
        {
            if (strPar == null || string.IsNullOrWhiteSpace(strPar))
            {
                return;
            }
            //导航页面
            _regionManager.Regions["PLCRegion"].RequestNavigate(strPar);
            //
            switch(strPar)
            {
                case "PLCReadView":
                    //发布面包靴
                    breadCrumbs.Clear();
                    breadCrumbs.Add(new CrumbViewModel { Name = "监控管理" });
                    breadCrumbs.Add(new CrumbViewModel { Name = "PLC点位监控",NavigateRegion="PLCPointView" });
                    breadCrumbs.Add(new CrumbViewModel { Name = "PLC变量读取" });
                    _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
                    break;
                case "PLCWriteView":
                    //发布面包靴
                    breadCrumbs.Clear();
                    breadCrumbs.Add(new CrumbViewModel { Name = "监控管理" });
                    breadCrumbs.Add(new CrumbViewModel { Name = "PLC点位监控", NavigateRegion = "PLCPointView" });
                    breadCrumbs.Add(new CrumbViewModel { Name = "PLC写入变量" });
                    _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
                    break;
            }
        }



        #region 命令绑定
        public DelegateCommand OnLoadCommand { set; get; }
        public DelegateCommand<string> ButtonNavigateCommand { set; get; }
        #endregion

    }
}
