﻿using AutoMapper;
using BizService;
using Microsoft.Extensions.Logging;
using Model.Dto;
using Model.Entities;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.SystemManageViewModel.Dialogs
{
   

    public class AddEditUserViewModel : BindableBase, IDialogAware
    {
        private readonly IEventAggregator _aggregator;
        private readonly IUserService _iUserService;
        private readonly IRoleService _iRoleService;
        private readonly IUserRoleService _iUserRoleService;
        private readonly IMapper _mapper;
        private readonly ILogger _logger;
        private List<UserDto> allUserInfoList = new List<UserDto>();
        private List<Role> allRoles = new List<Role>();
       
        private int id = 0;
        public AddEditUserViewModel(IEventAggregator aggregator, IUserService iUserService, IRoleService iRoleService, IUserRoleService iUserRoleService,IMapper mapper, ILogger logger)
        {
            _aggregator = aggregator;
            _iUserService = iUserService;
            _iRoleService = iRoleService;
            _iUserRoleService= iUserRoleService;
            _mapper = mapper;
            _logger = logger;
            CloseCommand = new DelegateCommand(Close);
            SureCommand = new DelegateCommand<string>(Sure);
            CancelCommand = new DelegateCommand(Close);

            GetUsers();
            GetRoles();

        }

     


        #region idialog接口实现
        public string Title { set; get; } = "新增用户";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {

        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            var getMsg = parameters.GetValues<int>("Key");
            ///值不为空，表示修改
            if (getMsg != null)
            {
                foreach (var item in getMsg)
                {
                    if (item != null)
                    {
                        try
                        {
                            Title = "修改用户";
                            id = item;
                            var findUser = allUserInfoList.FirstOrDefault(x => x.Id == id);
                            if (findUser != null)
                            {
                                UserName = findUser.UserName;
                                PassWord = findUser.Password;
                                PassWordAgain = findUser.Password;
                                Describe = findUser.Description;
                            }
                            //查找角色
                            var findUserRole = _iUserRoleService.QueryList().FirstOrDefault(x => x.UserId == id);
                            if (findUserRole != null)
                            {
                                int roleId = (int)findUserRole.RoleId;
                                SelectRole = allRoles.FirstOrDefault(x => x.Id == roleId)?.Name;
                            }
                        }
                        catch(Exception ex)
                        {
                            _logger.LogError(ex.ToString());
                        }
                       
                    }

                }

            }
        }

        #endregion
        #region 私有方法

       
        /// <summary>
        /// 判断输入的数据
        /// </summary>
        /// <param name="input"></param>
        /// <returns></returns>
     
     
        private void Close()
        {
            RequestClose?.Invoke(new DialogResult(ButtonResult.Cancel));
        }
        /// <summary>
        /// 确认
        /// </summary>
        /// <param name="obj"></param>
        private void Sure(string obj)
        {
            if (string.IsNullOrEmpty(UserName))
            {
                MessageBox.Show("请填写用户名", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (string.IsNullOrEmpty(PassWord)|| string.IsNullOrEmpty(PassWordAgain))
            {
                MessageBox.Show("请填写密码！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (string.IsNullOrEmpty(SelectRole))
            {
                MessageBox.Show("请选择角色！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (PassWord != PassWordAgain)
            {
               
                 MessageBox.Show("两次密码不一致！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                 return;

            }
            //判断是否存在用户名
            
            var findResult = allUserInfoList.FirstOrDefault(x => x.UserName == UserName);
            if (findResult != null)
            {
                if (Title == "新增用户")
                {
                    MessageBox.Show("已存在此用户名！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                    return;
                }
                else
                {
                    //修改时,若查到其他的用户名和这个重复
                    if(findResult.Id!= id)
                    {
                        MessageBox.Show("已存在此用户名！", "提示", MessageBoxButton.OK, MessageBoxImage.Information);
                        return;
                    }
                }
            }
          
     
            if (Title == "新增用户")
            {
                AddUser();
            }
            else
            {
                EditUser();
               
            }

            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
        }

        private void AddUser()
        {
           
            //添加到数据库user表中
            _iUserService.Add(new User()
            {
                UserName = UserName,
                Password = PassWord,
                Description = Describe
            });
            //查找添加的userid
            int newUserId = 0;
            var findId = _iUserService.QueryList().FirstOrDefault(x => x.UserName == UserName);
            if (findId != null)
            {
                newUserId = findId.Id;
            }
            //添加到数据库useRole表中
            bool isAdd=_iUserRoleService.Add(new UserRole()
            {
                UserId = newUserId,
                RoleId = allRoles.FirstOrDefault(x => x.Name == (SelectRole)).Id
            });
            if(isAdd)
            {
                MessageBox.Show("添加用户成功", "提示", MessageBoxButton.OK, MessageBoxImage.Information);

            }

        }
        private void EditUser()
        {
            User user = new User()
            {
                Id=id,
                UserName = UserName,
                Password = PassWord,
                Description = Describe

            };
            //修改到数据库user表中
            _iUserService.Edit(user);
            var userRole = _iUserRoleService.Find(id);
            if(userRole!=null)
            {
                userRole.RoleId = allRoles.FirstOrDefault(x => x.Name == (SelectRole)).Id;
                bool isedit=_iUserRoleService.Edit(userRole);
                if(isedit)
                {
                    MessageBox.Show("修改用户成功", "提示", MessageBoxButton.OK, MessageBoxImage.Information);

                }
            }
         

        }
        /// <summary>
        /// 获取角色
        /// </summary>
        private void GetRoles()
        {
            allRoles= _iRoleService.QueryList();
           
            foreach(var item in allRoles)
            {
                Roles.Add(item.Name);
            }
        }

        private void GetUsers()
        {
            var users = _iUserService.QueryList();
            allUserInfoList = _mapper.Map<List<User>, List<UserDto>>(users);
        }
        #endregion



        #region 命令绑定
        public DelegateCommand CloseCommand { set; get; }
        public DelegateCommand<string> SureCommand { set; get; }
        public DelegateCommand CancelCommand { set; get; }
      


        #endregion
        #region 变量绑定
        private string userName;
        public string UserName
        {
            get { return userName; }
            set { userName = value; RaisePropertyChanged(); }
        }
        private string passWord;
        public string PassWord
        {
            get { return passWord; }
            set { passWord = value; RaisePropertyChanged(); }
        }

        private string passWordAgain;
        public string PassWordAgain
        {
            get { return passWordAgain; }
            set { passWordAgain = value; RaisePropertyChanged(); }
        }
        private ObservableCollection<string> roles=new ObservableCollection<string>() ;
        public ObservableCollection<string> Roles
        {
            get { return roles; }
            set { roles = value; RaisePropertyChanged(); }
        }
        private string selectRole;
        public string SelectRole
        {
            get { return selectRole; }
            set { selectRole = value; RaisePropertyChanged(); }
        }

      
        private string describe;
        public string Describe
        {
            get { return describe; }
            set { describe = value; RaisePropertyChanged(); }
        }
 
        #endregion
    }
}
