﻿using AutoMapper;
using BizService;
using Microsoft.Extensions.Logging;
using Model.Dto;
using Model.Entities;
using PLCTool.Common;
using PLCTool.Controls;
using PLCTool.Events;
using PLCTool.Models;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.SystemManageViewModel
{
   
    public class RoleManageViewModel : BindableBase
    {
        private readonly IUserService _iUserService;
        private readonly IRoleService _iRoleService;
        private readonly ILogger _logger;
        private readonly IMapper _mapper;
        private readonly IDialogService _dialog;
        private readonly IEventAggregator _aggregator;
        private List<RoleDto> allRoleInfoList = new List<RoleDto>();

        public RoleManageViewModel(IUserService iUserService, IRoleService iRoleService, IMapper mapper, ILogger logger, IDialogService dialog, IEventAggregator aggregator)
        {

            _iUserService = iUserService;
            _iRoleService = iRoleService;
            _mapper = mapper;
            _logger = logger;
            _dialog = dialog;
            _aggregator = aggregator;
            AddCommand = new DelegateCommand<object>(AddUser);
            EditCommand = new DelegateCommand<object>(EditUser);
            DeleteCommand = new DelegateCommand<object>(Delete);
            OnLoadCommand = new DelegateCommand(OnLoad);
            QueryCommand = new DelegateCommand<object>(Query);
            AuthoMenuCommand = new DelegateCommand<object>(AuthoMenu);
            AuthoProjectCommand = new DelegateCommand<object>(AuthoProject);
        }

   



        #region 私有方法
        private void OnLoad()
        {
            GetAllRoles();
            //发布面包靴
            List<CrumbViewModel> breadCrumbs = new List<CrumbViewModel>();
            breadCrumbs.Add(new CrumbViewModel { Name = "系统管理" });
            breadCrumbs.Add(new CrumbViewModel { Name = "角色管理", NavigateRegion = "RoleManageView" });
            _aggregator.GetEvent<BreadEvent>().Publish(breadCrumbs);
        }
        private void AddUser(object obj)
        {      //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(true);
            _dialog.ShowDialog("AddEditRoleView", async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    GetAllRoles();
                }

            });
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(false);
        }

        private void EditUser(object obj)
        {
            int id = Convert.ToInt32(obj);

            DialogParameters parm = new DialogParameters();
            parm.Add("Key", id);
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(true);
            _dialog.ShowDialog("AddEditRoleView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    GetAllRoles();
                }

            });
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(false);
        }

        private void Delete(object obj)
        {
            int id = Convert.ToInt32(obj);
            if (_iRoleService.Find(id)?.Name == "系统管理员")
            {
                MessageBox.Show("系统管理员角色无法删除！", "确认", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            if (id==Appsession.RoleId)
            {
                MessageBox.Show("此角色与当前登录角色相同，无法删除！", "确认", MessageBoxButton.OK, MessageBoxImage.Information);
                return;
            }
            MessageBoxResult boxResult = MessageBox.Show("确认删除此条数据?", "确认", MessageBoxButton.OKCancel, MessageBoxImage.Question);
            if (boxResult == MessageBoxResult.OK)
            {
                var del = _iRoleService.Delete(id);
                if (del)
                {
                    MessageBox.Show("删除成功!", "确认", MessageBoxButton.OK, MessageBoxImage.Information);
                    GetAllRoles();
                }

            }
        }
        private void GetAllRoles()
        {
            var roles = _iRoleService.QueryList();
            allRoleInfoList = _mapper.Map<List<Role>, List<RoleDto>>(roles);
            RoleInfoList = new ObservableCollection<RoleDto>(allRoleInfoList);
        }
        private void AuthoProject(object obj)
        {
            int id = Convert.ToInt32(obj);

            DialogParameters parm = new DialogParameters();
            parm.Add("Key", id);
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(true);
            _dialog.ShowDialog("RoleWithProjectView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    GetAllRoles();
                }

            });
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(false);
        }

        private void AuthoMenu(object obj)
        {
            int id = Convert.ToInt32(obj);

            DialogParameters parm = new DialogParameters();
            parm.Add("Key", id);
            //蒙层显示
            _aggregator.GetEvent<MaskEvent>().Publish(true);
            _dialog.ShowDialog("RoleWithMenuView", parm, async callback =>
            {
                if (callback.Result == ButtonResult.OK)
                {
                    GetAllRoles();
                }

            });
            //蒙层不显示
            _aggregator.GetEvent<MaskEvent>().Publish(false);
        }

        /// <summary>
        /// 判断输入的数据
        /// </summary>
        /// <param name="input"></param>

        /// <summary>
        /// 获取PLC配置
        /// </summary>

        /// <summary>
        /// 查询
        /// </summary>
        /// <param name="obj"></param>
        private void Query(object obj)
        {
            var conUsers = (from a in allRoleInfoList
                            where (string.IsNullOrEmpty(RoleName) ? true : (a.Name.Contains(RoleName)))

                            select a).ToList();
            //默认显示的第一页

            RoleInfoList = new ObservableCollection<RoleDto>(conUsers);
        }

        #endregion
        #region 数据绑定
        private ObservableCollection<RoleDto> roleInfoList = new ObservableCollection<RoleDto>();
        public ObservableCollection<RoleDto> RoleInfoList
        {
            get { return roleInfoList; }
            set { roleInfoList = value; RaisePropertyChanged(); }
        }
        private string roleName = string.Empty;
        public string RoleName
        {
            get { return roleName; }
            set { roleName = value; RaisePropertyChanged(); }
        }

        #endregion

        #region 命令绑定
        public DelegateCommand OnLoadCommand { set; get; }
        public DelegateCommand<object> AddCommand { set; get; }
        public DelegateCommand<object> EditCommand { set; get; }
        public DelegateCommand<object> DeleteCommand { set; get; }
        public DelegateCommand<object> QueryCommand { set; get; }
        public DelegateCommand<object> AuthoMenuCommand { set; get; }
        public DelegateCommand<object> AuthoProjectCommand { set; get; }
        #endregion
    }
}
